#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module McOn
            class Airport < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'f31383f4-77d8-41a3-bd2a-a1dd2c5ab102' => OperationConfig.new("/loyalty/v1/airport/dmc", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits"]),
                    '52c307f7-adbe-4772-96a7-d606bc0704ff' => OperationConfig.new("/loyalty/v1/airport/history", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits","preferredLanguage","transactionDateFrom","transactionDateTo"]),
                    'c96fa1fc-ca66-4639-a08d-6235394a919d' => OperationConfig.new("/loyalty/v1/airport/lounges", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits","searchText","preferredLanguage"]),
                    '61e3633c-115e-42c5-98af-4237141019f4' => OperationConfig.new("/loyalty/v1/airport/lounges/{loungeCode}/detail", "query", ["x-client-correlation-id"], ["userId","panLastFourDigits","preferredLanguage"]),
                    'd256fb8d-b654-43b4-a97e-2d1f185bd0da' => OperationConfig.new("/loyalty/v1/users/{userId}/airport", "query", ["x-client-correlation-id"], ["panLastFourDigits"]),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public







                def self.getDMC(criteria)
                    #
                    #Query objects of type Airport by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Airport] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("f31383f4-77d8-41a3-bd2a-a1dd2c5ab102",Airport.new(criteria))
                end







                def self.getLoungeHistory(criteria)
                    #
                    #Query objects of type Airport by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Airport] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("52c307f7-adbe-4772-96a7-d606bc0704ff",Airport.new(criteria))
                end







                def self.getLounges(criteria)
                    #
                    #Query objects of type Airport by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Airport] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("c96fa1fc-ca66-4639-a08d-6235394a919d",Airport.new(criteria))
                end







                def self.getLoungeDetail(criteria)
                    #
                    #Query objects of type Airport by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Airport] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("61e3633c-115e-42c5-98af-4237141019f4",Airport.new(criteria))
                end







                def self.userAirportRegistrationStatus(criteria)
                    #
                    #Query objects of type Airport by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Airport] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("d256fb8d-b654-43b4-a97e-2d1f185bd0da",Airport.new(criteria))
                end


            end
        end
    end
end







