#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module McOn
            class Benefits < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    '23aa63ec-82a4-4135-bde2-7f90dc27ebdf' => OperationConfig.new("/loyalty/v1/benefits/assigned", "query", ["x-client-correlation-id"], ["ica","userId","panLastFourDigits","channel","preferredLanguage"]),
                    'da6073ef-5bb2-4feb-ad63-05b118f76205' => OperationConfig.new("/loyalty/v1/benefits/{benefitId}/detail", "query", ["x-client-correlation-id"], ["ica","channel","preferredLanguage"]),
                    'c501d04f-0914-46be-a385-f8811487604f' => OperationConfig.new("/loyalty/v1/benefits", "query", ["x-client-correlation-id"], ["ica","cardProductType","channel","preferredLanguage"]),
                    'b0b687dc-88eb-4ad5-82b8-434ce76ac3d0' => OperationConfig.new("/loyalty/v1/benefits", "create", ["x-client-correlation-id"], []),
                    '6bd3a165-8714-4d48-b3d8-dc921330b37a' => OperationConfig.new("/loyalty/v1/benefits/programterms", "query", ["x-client-correlation-id"], ["ica","preferredLanguage"]),
                    'f234385e-e12b-4d76-b217-7fc2a5123d95' => OperationConfig.new("/loyalty/v1/users/{userId}/benefits", "query", ["x-client-correlation-id"], ["panLastFourDigits"]),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public







                def self.getAssignedBenefits(criteria)
                    #
                    #Query objects of type Benefits by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Benefits] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("23aa63ec-82a4-4135-bde2-7f90dc27ebdf",Benefits.new(criteria))
                end







                def self.getBenefitDetail(criteria)
                    #
                    #Query objects of type Benefits by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Benefits] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("da6073ef-5bb2-4feb-ad63-05b118f76205",Benefits.new(criteria))
                end







                def self.getBenefits(criteria)
                    #
                    #Query objects of type Benefits by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Benefits] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("c501d04f-0914-46be-a385-f8811487604f",Benefits.new(criteria))
                end


                def self.selectBenefits(mapObj)
                    #
                    #Creates object of type Benefits
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Benefits] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("b0b687dc-88eb-4ad5-82b8-434ce76ac3d0", Benefits.new(mapObj))
                end












                def self.getProgramTerms(criteria)
                    #
                    #Query objects of type Benefits by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Benefits] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("6bd3a165-8714-4d48-b3d8-dc921330b37a",Benefits.new(criteria))
                end







                def self.userBenefitsRegistrationStatus(criteria)
                    #
                    #Query objects of type Benefits by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Benefits] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("f234385e-e12b-4d76-b217-7fc2a5123d95",Benefits.new(criteria))
                end


            end
        end
    end
end







