#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module McOn
            class BundleProfile < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    'ccff9a33-58af-4940-b9e8-1558edd52538' => OperationConfig.new("/bundle/profile/v1/users", "create", ["x-client-correlation-id"], []),
                    'c2c54b4d-2b23-4ae7-b537-0d1f94ec7b83' => OperationConfig.new("/bundle/profile/v1/users/{userId}", "delete", ["x-client-correlation-id"], []),
                    'd74ab067-a623-4398-b1f6-c821d7f948a5' => OperationConfig.new("/bundle/profile/v1/users/{userId}/patch", "create", ["x-client-correlation-id"], []),
                    '0db1446a-d974-4d1b-93ba-bb671d16b172' => OperationConfig.new("/bundle/profile/v1/users/{userId}", "read", ["x-client-correlation-id"], []),
                    'ae94a9c0-80b9-4fa8-b71e-2ffddd7c94cb' => OperationConfig.new("/bundle/profile/v1/users/{userId}", "update", ["x-client-correlation-id"], []),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public


                def self.createUser(mapObj)
                    #
                    #Creates object of type BundleProfile
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [BundleProfile] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("ccff9a33-58af-4940-b9e8-1558edd52538", BundleProfile.new(mapObj))
                end










                def self.deleteUserById(id, map = nil)
                    #Delete object of type BundleProfile by id

                    #@param [String] id
                    #@param [Dict] map, containing additional parameters
                    #@return [BundleProfile] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status


                    mapObj = BundleProfile.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !map.nil?
                        if map.instance_of? RequestMap
                          mapObj.setAll(map.getObject())
                        else
                          mapObj.setAll(map)
                        end
                    end

                    return self.execute("c2c54b4d-2b23-4ae7-b537-0d1f94ec7b83", mapObj)
                end


                def deleteUser
                    #
                    #Delete object of type BundleProfile

                    #@param [String] id
                    #@return [BundleProfile] of the response of the deleted instance.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.class.execute("c2c54b4d-2b23-4ae7-b537-0d1f94ec7b83", self)
                end




                def self.patchUser(mapObj)
                    #
                    #Creates object of type BundleProfile
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [BundleProfile] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("d74ab067-a623-4398-b1f6-c821d7f948a5", BundleProfile.new(mapObj))
                end











                def self.readUser(id, criteria = nil)
                    #
                    #Returns objects of type BundleProfile by id and optional criteria
                    #@param [String] id
                    #@param [Dict] criteria
                    #@return [BundleProfile] object representing the response
                    #@raise [APIException] an exception from the response status

                    mapObj = BundleProfile.new
                    if !(id.nil? || id.to_s.empty?)
                      mapObj.set("id", id)
                    end
                    if !criteria.nil?
                        if criteria.instance_of? RequestMap
                          mapObj.setAll(criteria.getObject())
                        else
                          mapObj.setAll(criteria)
                        end
                    end

                    return self.execute("0db1446a-d974-4d1b-93ba-bb671d16b172",BundleProfile.new(mapObj))
                end




                def updateUser
                    #
                    #Updates an object of type BundleProfile
                    #
                    #@return [BundleProfile] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #
                    return self.class.execute("ae94a9c0-80b9-4fa8-b71e-2ffddd7c94cb",self)
                end







            end
        end
    end
end







