#
# Copyright (c) 2016 MasterCard International Incorporated
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without modification, are
# permitted provided that the following conditions are met:
#
# Redistributions of source code must retain the above copyright notice, this list of
# conditions and the following disclaimer.
# Redistributions in binary form must reproduce the above copyright notice, this list of
# conditions and the following disclaimer in the documentation and/or other materials
# provided with the distribution.
# Neither the name of the MasterCard International Incorporated nor the names of its
# contributors may be used to endorse or promote products derived from this software
# without specific prior written permission.
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY
# EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
# OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT
# SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
# INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
# TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
# OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
# IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
# IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#


require "mastercard/core/model"
require "mastercard/core/baseobject"

module MasterCard
    module API
        module McOn
            class Offers < MasterCard::Core::Model::BaseObject
                include MasterCard::Core::Model
                #

                @__store = {
                    '5892b910-2ea7-4c98-8b09-77ae08c54a15' => OperationConfig.new("/loyalty/v1/offers", "query", ["x-client-correlation-id"], ["userId","preferredLanguage","sort","category","featured","favorite","partner"]),
                    'a8ca9113-dc6f-4050-b593-e70e43f5e338' => OperationConfig.new("/loyalty/v1/offers/{offerId}/activate", "create", ["x-client-correlation-id"], []),
                    '9e1f807c-ef33-4fd6-87c5-87f6ccfe0f82' => OperationConfig.new("/loyalty/v1/offers/{offerId}/detail", "query", ["x-client-correlation-id"], ["userId","preferredLanguage"]),
                    '5f0d5b7d-83d3-4279-a9f7-92ad9953a5ff' => OperationConfig.new("/loyalty/v1/offers/{offerId}/favorite", "create", ["x-client-correlation-id"], []),
                    '2183962d-aba8-4f1d-b6cf-325f7192aa87' => OperationConfig.new("/loyalty/v1/offers/{offerId}/redeem", "create", ["x-client-correlation-id"], []),
                    'fc6debb0-fc50-487e-91bd-2889eac11735' => OperationConfig.new("/loyalty/v1/offers/{offerId}/unfavorite", "create", ["x-client-correlation-id"], []),
                    'eb7846df-0f91-4fa6-a2c7-11b5bb153da0' => OperationConfig.new("/loyalty/v1/offers/promo", "create", ["x-client-correlation-id"], []),
                    '92c794bd-5e99-4619-9a0a-f280c9fc6d97' => OperationConfig.new("/loyalty/v1/offers/redeemed", "query", ["x-client-correlation-id"], ["userId","preferredLanguage"]),
                    'f3741d6d-1b72-4116-bba5-3c9e0a90c3df' => OperationConfig.new("/loyalty/v1/points/expiring", "query", ["x-client-correlation-id"], ["userId"]),
                    'cd7da981-da72-4720-9177-d82316c40088' => OperationConfig.new("/loyalty/v1/points", "query", ["x-client-correlation-id"], ["userId"]),
                    '42aec0d3-88ea-4b9f-ad85-fe2c28d7e30c' => OperationConfig.new("/loyalty/v1/users/{userId}/offers", "query", ["x-client-correlation-id"], []),
                    '557e5827-954c-427d-84dc-e3e74643201f' => OperationConfig.new("/loyalty/v1/vouchers", "query", ["x-client-correlation-id"], ["userId"]),
                    '058c47fb-6873-4a58-b396-9547aa4f076e' => OperationConfig.new("/loyalty/v1/vouchers/{voucherId}/detail", "query", ["x-client-correlation-id"], ["userId"]),
                    
                }

                protected

                def self.getOperationConfig(operationUUID)
                    if @__store.key?(operationUUID)
                        return @__store[operationUUID]
                    end
                    raise NotImplementedError.new("Invalid operationUUID supplied:"+ operationUUID)
                end

                def self.getOperationMetadata()
                    return OperationMetadata.new(ResourceConfig.instance.getVersion(), ResourceConfig.instance.getHost(), ResourceConfig.instance.getContext(), ResourceConfig.instance.getJsonNative(), ResourceConfig.instance.getContentTypeOverride())
                end

                public







                def self.getOffers(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("5892b910-2ea7-4c98-8b09-77ae08c54a15",Offers.new(criteria))
                end


                def self.activateOffer(mapObj)
                    #
                    #Creates object of type Offers
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Offers] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("a8ca9113-dc6f-4050-b593-e70e43f5e338", Offers.new(mapObj))
                end












                def self.getOfferDetail(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("9e1f807c-ef33-4fd6-87c5-87f6ccfe0f82",Offers.new(criteria))
                end


                def self.favoriteOffer(mapObj)
                    #
                    #Creates object of type Offers
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Offers] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("5f0d5b7d-83d3-4279-a9f7-92ad9953a5ff", Offers.new(mapObj))
                end







                def self.redeemOffer(mapObj)
                    #
                    #Creates object of type Offers
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Offers] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("2183962d-aba8-4f1d-b6cf-325f7192aa87", Offers.new(mapObj))
                end







                def self.unfavoriteOffer(mapObj)
                    #
                    #Creates object of type Offers
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Offers] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("fc6debb0-fc50-487e-91bd-2889eac11735", Offers.new(mapObj))
                end







                def self.submitOfferPromo(mapObj)
                    #
                    #Creates object of type Offers
                    #
                    #@param Dict mapObj, containing the required parameters to create a new object
                    #@return [Offers] of the response of created instance.
                    #@raise [APIException] an exception from the response status
                    return self.execute("eb7846df-0f91-4fa6-a2c7-11b5bb153da0", Offers.new(mapObj))
                end












                def self.getRedeemedOffers(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("92c794bd-5e99-4619-9a0a-f280c9fc6d97",Offers.new(criteria))
                end







                def self.getPointsExpiring(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("f3741d6d-1b72-4116-bba5-3c9e0a90c3df",Offers.new(criteria))
                end







                def self.getPoints(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("cd7da981-da72-4720-9177-d82316c40088",Offers.new(criteria))
                end







                def self.userOffersRegistrationStatus(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("42aec0d3-88ea-4b9f-ad85-fe2c28d7e30c",Offers.new(criteria))
                end







                def self.getVouchers(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("557e5827-954c-427d-84dc-e3e74643201f",Offers.new(criteria))
                end







                def self.getVoucherDetail(criteria)
                    #
                    #Query objects of type Offers by id and optional criteria
                    #@param [Dict] criteria
                    #@return [Offers] object representing the response.
                    #@raise [APIException] an exception from the response status
                    #

                    return self.execute("058c47fb-6873-4a58-b396-9547aa4f076e",Offers.new(criteria))
                end


            end
        end
    end
end







